@@ -44,7 +44,7 @@ from update_checker import update_check
 from warnings import simplefilter, warn, warn_explicit
 
 
-__version__ = '2.1.0'
+__version__ = '2.1.1'
 UA_STRING = '%%s PRAW/%s Python/%s %s' % (__version__,
                                           sys.version.split()[0],
                                           platform.platform(True))
@@ -395,7 +395,10 @@ class BaseReddit(object):
             automatically make additional requests as necessary).
         :param place_holder: if not None, the method will fetch `limit`
             content, stopping if it finds content with `id` equal to
-            `place_holder`.
+            `place_holder`. The place_holder item is the last item to be
+            yielded from this generator. Note that the use of `place_holder` is
+            not 100% reliable as the place holder item may no longer exist due
+            to being removed or deleted.
         :param root_field: indicates the field in the json response that holds
             the data. Most objects use 'data', however some (flairlist) don't
             have the 'data' object. Use None for the root object.
@@ -403,8 +406,8 @@ class BaseReddit(object):
             contains the list of things. Most objects use 'children'.
         :param after_field: indicates the field which holds the after item
             element
-        :type place_holder: a string corresponding to a reddit content id, e.g.
-            't3_asdfasdf'
+        :type place_holder: a string corresponding to a reddit base36 id
+            without prefix, e.g. 'asdfasdf'
         :returns: a list of reddit content, of type Subreddit, Comment,
             Submission or user flair.
 
@@ -673,7 +676,8 @@ class UnauthenticatedReddit(BaseReddit):
         params = {'name': name}
         data = self.request_json(self.config['flairlist'] %
                                  six.text_type(subreddit), params=params)
-        if not data['users'] or data['users'][0]['user'] != name:
+        if not data['users'] or \
+                data['users'][0]['user'].lower() != name.lower():
             return None
         return data['users'][0]
 
@@ -1176,7 +1180,10 @@ class ModConfigMixin(AuthenticatedReddit):
                      domain_sidebar=False, header_hover_text='',
                      prev_description_id=None,
                      prev_public_description_id=None, wikimode='disabled',
-                     wiki_edit_age=30, wiki_edit_karma=100, **kwargs):
+                     wiki_edit_age=30, wiki_edit_karma=100,
+                     submit_link_label='', submit_text_label='',
+                     exclude_banned_modqueue=False, comment_score_hide_mins=0,
+                     **kwargs):
         """Set the settings for the given subreddit.
 
         :param subreddit: Must be  a subreddit object.
@@ -1184,22 +1191,27 @@ class ModConfigMixin(AuthenticatedReddit):
 
         """
         data = {'sr': subreddit.fullname,
-                'title': title,
-                'public_description': public_description,
-                'description': description,
-                'lang': language,
-                'type': subreddit_type,
-                'link_type': content_options,
-                'over_18': 'on' if over_18 else 'off',
                 'allow_top': 'on' if default_set else 'off',
-                'show_media': 'on' if show_media else 'off',
+                'comment_score_hide_mins': comment_score_hide_mins,
+                'description': description,
                 'domain': domain or '',
                 'domain_css': 'on' if domain_css else 'off',
                 'domain_sidebar': 'on' if domain_sidebar else 'off',
+                'exclude_banned_modqueue': ('on' if exclude_banned_modqueue
+                                            else 'off'),
                 'header-title': header_hover_text or '',
-                'wikimode': wikimode,
+                'lang': language,
+                'link_type': content_options,
+                'over_18': 'on' if over_18 else 'off',
+                'public_description': public_description,
+                'show_media': 'on' if show_media else 'off',
+                'submit_link_label': submit_link_label or '',
+                'submit_text_label': submit_text_label or '',
+                'title': title,
+                'type': subreddit_type,
                 'wiki_edit_age': six.text_type(wiki_edit_age),
-                'wiki_edit_karma': six.text_type(wiki_edit_karma)}
+                'wiki_edit_karma': six.text_type(wiki_edit_karma),
+                'wikimode': wikimode}
         if prev_description_id is not None:
             data['prev_description_id'] = prev_description_id
         if prev_public_description_id is not None:
