@@ -31,8 +31,7 @@ from praw import (AuthenticatedReddit as AR, ModConfigMixin as MCMix,
                   SubmitMixin, SubscribeMixin, UnauthenticatedReddit as UR)
 from praw.decorators import alias_function, limit_chars, restrict_access
 from praw.errors import ClientException
-from praw.helpers import (_get_section, _get_sorter, _modify_relationship,
-                          _request)
+from praw.internal import _get_section, _get_sorter, _modify_relationship
 
 
 REDDITOR_KEYS = ('approved_by', 'author', 'banned_by', 'redditor')
@@ -46,9 +45,11 @@ class RedditContentObject(object):
     def from_api_response(cls, reddit_session, json_dict):
         """Return an instance of the appropriate class from the json_dict."""
         if cls == WikiPage:  # Temporary HACK for WikiPage
-            parts = reddit_session._request_url.rsplit('/', 3)
-            subreddit = parts[1]
-            page = parts[3].split('.')[0]
+            # pylint: disable-msg=W0212
+            parts = reddit_session._request_url.split('/', 6)
+            # pylint: enable-msg=W0212
+            subreddit = parts[4]
+            page = parts[6].split('.', 1)[0]
             return cls(reddit_session, subreddit, page, json_dict=json_dict)
         return cls(reddit_session, json_dict=json_dict)
 
@@ -102,7 +103,7 @@ class RedditContentObject(object):
         return retval
 
     def _get_json_dict(self):
-        # pylint: disable-msg=W0212
+        # (disbled for entire function) pylint: disable-msg=W0212
 
         # OAuth handling needs to be special cased here. For instance, the user
         # might be calling a method on a Subreddit object that requires first
@@ -156,8 +157,8 @@ class Moderatable(RedditContentObject):
         """Approve object.
 
         This reverts a removal, resets the report counter, marks it with a
-        green checkmark (only visible to other moderators) on the webend and
-        sets the approved_by attribute to the logged in user.
+        green check mark (only visible to other moderators) on the website view
+        and sets the approved_by attribute to the logged in user.
 
         :returns: The json response from the server.
 
@@ -168,7 +169,7 @@ class Moderatable(RedditContentObject):
         urls = [self.reddit_session.config[x] for x in ['modqueue', 'spam']]
         if isinstance(self, Submission):
             urls += self.subreddit._listing_urls  # pylint: disable-msg=W0212
-        _request.evict(urls)  # pylint: disable-msg=E1101
+        self.reddit_session.evict(urls)
         return response
 
     @restrict_access(scope='modposts')
@@ -204,7 +205,7 @@ class Moderatable(RedditContentObject):
 
         The object is removed from the subreddit listings and placed into the
         spam listing. If spam is set to True, then the automatic spam filter
-        will try to remove objects with similair attributes in the future.
+        will try to remove objects with similar attributes in the future.
 
         :returns: The json response from the server.
 
@@ -216,7 +217,7 @@ class Moderatable(RedditContentObject):
         urls = [self.reddit_session.config[x] for x in ['modqueue', 'spam']]
         if isinstance(self, Submission) and hasattr(self, 'subreddit'):
             urls += self.subreddit._listing_urls  # pylint: disable-msg=W0212
-        _request.evict(urls)  # pylint: disable-msg=E1101
+        self.reddit_session.evict(urls)
         return response
 
     def undistinguish(self):
@@ -250,8 +251,7 @@ class Editable(RedditContentObject):
         url = self.reddit_session.config['del']
         data = {'id': self.fullname}
         response = self.reddit_session.request_json(url, data=data)
-        # pylint: disable-msg=E1101
-        _request.evict([self.reddit_session.config['user']])
+        self.reddit_session.evict(self.reddit_session.config['user'])
         return response
 
     @restrict_access(scope='edit')
@@ -265,8 +265,7 @@ class Editable(RedditContentObject):
         data = {'thing_id': self.fullname,
                 'text': text}
         response = self.reddit_session.request_json(url, data=data)
-        # pylint: disable-msg=E1101
-        _request.evict([self.reddit_session.config['user']])
+        self.reddit_session.evict(self.reddit_session.config['user'])
         # REDDIT: reddit's end should only ever return a single comment
         return response['data']['things'][0]
 
@@ -288,7 +287,8 @@ class Hideable(RedditContentObject):
         response = self.reddit_session.request_json(url, data=data)
         # pylint: disable-msg=W0212
         urls = [urljoin(self.reddit_session.user._url, 'hidden')]
-        _request.evict(urls)
+        # pylint: enable-msg=W0212
+        self.reddit_session.evict(urls)
         return response
 
     def unhide(self):
@@ -326,14 +326,15 @@ class Inboxable(RedditContentObject):
         :returns: A Comment object for the newly created comment (reply).
 
         """
-        # pylint: disable-msg=E1101,W0212
+        # pylint: disable-msg=W0212
         response = self.reddit_session._add_comment(self.fullname, text)
+        # pylint: enable-msg=W0212
+        urls = [self.reddit_session.config['inbox']]
         if isinstance(self, Comment):
-            _request.evict([self.reddit_session.config['inbox'],
-                            self.submission.permalink])
+            urls.append(self.submission.permalink)
         elif isinstance(self, Message):
-            _request.evict([self.reddit_session.config['inbox'],
-                            self.reddit_session.config['sent']])
+            urls.append(self.reddit_session.config['sent'])
+        self.reddit_session.evict(urls)
         return response
 
 
@@ -341,7 +342,7 @@ class Messageable(RedditContentObject):
 
     """Interface for RedditContentObjects that can be messaged."""
 
-    _methods = (('send_message', PMMix.send_message),)
+    _methods = (('send_message', PMMix),)
 
 
 class Refreshable(RedditContentObject):
@@ -382,9 +383,11 @@ class Reportable(RedditContentObject):
         data = {'id': self.fullname}
         response = self.reddit_session.request_json(url, data=data)
         # Reported objects are automatically hidden as well
-        # pylint: disable-msg=E1101,W0212
-        _request.evict([self.reddit_session.config['user'],
-                        urljoin(self.reddit_session.user._url, 'hidden')])
+        # pylint: disable-msg=W0212
+        urls = [self.reddit_session.config['user'],
+                urljoin(self.reddit_session.user._url, 'hidden')]
+        # pylint: enable-msg=W0212
+        self.reddit_session.evict(urls)
         return response
 
 
@@ -403,8 +406,7 @@ class Saveable(RedditContentObject):
         data = {'id': self.fullname,
                 'executed': 'unsaved' if unsave else 'saved'}
         response = self.reddit_session.request_json(url, data=data)
-        # pylint: disable-msg=E1101
-        _request.evict([self.reddit_session.config['saved']])
+        self.reddit_session.evict(self.reddit_session.config['saved'])
         return response
 
     def unsave(self):
@@ -460,7 +462,8 @@ class Voteable(RedditContentObject):
             # pylint: disable-msg=W0212
             urls = [urljoin(self.reddit_session.user._url, 'disliked'),
                     urljoin(self.reddit_session.user._url, 'liked')]
-            _request.evict(urls)
+            # pylint: enable-msg=W0212
+            self.reddit_session.evict(urls)
         return self.reddit_session.request_json(url, data=data)
 
 
@@ -487,10 +490,13 @@ class Comment(Editable, Inboxable, Moderatable, Reportable, Voteable):
         """Submission isn't set on __init__ thus we need to update it."""
         # pylint: disable-msg=W0212
         submission._comments_by_id[self.name] = self
+        # pylint: enable-msg=W0212
         self._submission = submission
         if self._replies:
             for reply in self._replies:
+                # pylint: disable-msg=W0212
                 reply._update_submission(submission)
+                # pylint: enable-msg=W0212
 
     @property
     def is_root(self):
@@ -510,6 +516,7 @@ class Comment(Editable, Inboxable, Moderatable, Reportable, Voteable):
             response = self.reddit_session.request_json(self.permalink)
             # pylint: disable-msg=W0212
             self._replies = response[1]['data']['children'][0]._replies
+            # pylint: enable-msg=W0212
         return self._replies
 
     @property
@@ -574,13 +581,16 @@ class MoreComments(RedditContentObject):
             # pylint: disable-msg=W0212
             children = [x for x in self.children if 't1_%s' % x
                         not in self.submission._comments_by_id]
+            # pylint: enable-msg=W0212
             if not children:
                 return None
             data = {'children': ','.join(children),
                     'link_id': self.submission.fullname,
                     'r': str(self.submission.subreddit)}
+            # pylint: disable-msg=W0212
             if self.submission._comment_sort:
                 data['where'] = self.submission._comment_sort
+            # pylint: enable-msg=W0212
             url = self.reddit_session.config['morechildren']
             response = self.reddit_session.request_json(url, data=data)
             self._comments = response['data']['things']
@@ -588,6 +598,7 @@ class MoreComments(RedditContentObject):
                 for comment in self._comments:
                     # pylint: disable-msg=W0212
                     comment._update_submission(self.submission)
+                    # pylint: enable-msg=W0212
         return self._comments
 
 
@@ -628,7 +639,7 @@ class Redditor(Messageable, Refreshable):
         :returns: The json response from the server.
 
         """
-        _request.evict([self.reddit_session.config['friends']])
+        self.reddit_session.evict(self.reddit_session.config['friends'])
         return _modify_relationship('friend')(self.reddit_session.user, self)
 
     def mark_as_read(self, messages, unread=False):
@@ -649,7 +660,9 @@ class Redditor(Messageable, Refreshable):
         else:
             raise ClientException('Invalid message type: %s' % type(messages))
         # pylint: disable-msg=W0212
-        return self.reddit_session._mark_as_read(ids, unread=unread)
+        retval = self.reddit_session._mark_as_read(ids, unread=unread)
+        # pylint: enable-msg=W0212
+        return retval
 
     def unfriend(self):
         """Unfriend the user.
@@ -657,7 +670,7 @@ class Redditor(Messageable, Refreshable):
         :returns: The json response from the server.
 
         """
-        _request.evict([self.reddit_session.config['friends']])
+        self.reddit_session.evict(self.reddit_session.config['friends'])
         return _modify_relationship('friend', unlink=True)(
             self.reddit_session.user, self)
 
@@ -747,7 +760,7 @@ class Submission(Editable, Hideable, Moderatable, Refreshable, Reportable,
         :param comment_limit: The desired number of comments to fetch. If <= 0
             fetch the default number for the session's user. If None, fetch the
             maximum possible.
-        :param comment_sort: The sort order for retrived comments. When None
+        :param comment_sort: The sort order for retrieved comments. When None
             use the default for the session's user.
         :param comments_only: Return only the list of comments.
 
@@ -814,9 +827,10 @@ class Submission(Editable, Hideable, Moderatable, Refreshable, Reportable,
         :returns: A Comment object for the newly created comment.
 
         """
-        # pylint: disable-msg=E1101, W0212
+        # pylint: disable-msg=W0212
         response = self.reddit_session._add_comment(self.fullname, text)
-        _request.evict([self.permalink])
+        # pylint: enable-msg=W0212
+        self.reddit_session.evict(self.permalink)
         return response
 
     @property
@@ -879,16 +893,16 @@ class Submission(Editable, Hideable, Moderatable, Refreshable, Reportable,
 
             # Insert into the tree or re-add to the list of more_comments
             for comment in new_comments:
+                # pylint: disable-msg=W0212
                 if isinstance(comment, MoreComments):
-                    # pylint: disable-msg=W0212
                     comment._update_submission(self)
                     heappush(more_comments, comment)
                 else:
-                    # pylint: disable-msg=W0212
-                    assert not comment._replies
                     # Replies needs to be an empty list
+                    assert not comment._replies
                     comment._replies = []
                     self._insert_comment(comment)
+                # pylint: enable-msg=W0212
 
         self._replaced_more = True
         return more_comments
@@ -896,6 +910,9 @@ class Submission(Editable, Hideable, Moderatable, Refreshable, Reportable,
     def set_flair(self, *args, **kwargs):
         """Set flair for this submission.
 
+        Convenience function that utilizes :meth:`.ModFlairMixin.set_flair`
+        populating both the `subreddit` and `item` parameters.
+
         :returns: The json response from the server.
 
         """
@@ -916,39 +933,40 @@ class Subreddit(Messageable, Refreshable):
 
     """A class for Subreddits."""
 
-    _methods = (('accept_moderator_invite', AR.accept_moderator_invite),
-                ('add_flair_template', MFMix.add_flair_template),
-                ('clear_flair_templates', MFMix.clear_flair_templates),
-                ('configure_flair', MFMix.configure_flair),
-                ('delete_flair', MFMix.delete_flair),
-                ('delete_image', MCMix.delete_image),
-                ('edit_wiki_page', AR.edit_wiki_page),
-                ('get_banned', MOMix.get_banned),
-                ('get_comments', UR.get_comments),
-                ('get_contributors', MOMix.get_contributors),
-                ('get_flair', UR.get_flair),
-                ('get_flair_list', MFMix.get_flair_list),
-                ('get_moderators', MOMix.get_moderators),
-                ('get_mod_log', MLMix.get_mod_log),
-                ('get_mod_queue', MOMix.get_mod_queue),
-                ('get_reports', MOMix.get_reports),
-                ('get_settings', MCMix.get_settings),
-                ('get_spam', MOMix.get_spam),
-                ('get_stylesheet', MOMix.get_stylesheet),
-                ('get_unmoderated', MOMix.get_unmoderated),
-                ('get_wiki_banned', MOMix.get_wiki_banned),
-                ('get_wiki_contributors', MOMix.get_wiki_contributors),
-                ('get_wiki_page', UR.get_wiki_page),
-                ('get_wiki_pages', UR.get_wiki_pages),
-                ('set_flair', MFMix.set_flair),
-                ('set_flair_csv', MFMix.set_flair_csv),
-                ('set_settings', MCMix.set_settings),
-                ('set_stylesheet', MCMix.set_stylesheet),
-                ('submit', SubmitMixin.submit),
-                ('subscribe', SubscribeMixin.subscribe),
-                ('unsubscribe', SubscribeMixin.unsubscribe),
-                ('update_settings', MCMix.update_settings),
-                ('upload_image', MCMix.upload_image))
+    _methods = (('accept_moderator_invite', AR),
+                ('add_flair_template', MFMix),
+                ('clear_flair_templates', MFMix),
+                ('configure_flair', MFMix),
+                ('delete_flair', MFMix),
+                ('delete_image', MCMix),
+                ('edit_wiki_page', AR),
+                ('get_banned', MOMix),
+                ('get_comments', UR),
+                ('get_contributors', MOMix),
+                ('get_flair', UR),
+                ('get_flair_list', MFMix),
+                ('get_moderators', UR),
+                ('get_mod_log', MLMix),
+                ('get_mod_queue', MOMix),
+                ('get_reports', MOMix),
+                ('get_settings', MCMix),
+                ('get_spam', MOMix),
+                ('get_stylesheet', MOMix),
+                ('get_unmoderated', MOMix),
+                ('get_wiki_banned', MOMix),
+                ('get_wiki_contributors', MOMix),
+                ('get_wiki_page', UR),
+                ('get_wiki_pages', UR),
+                ('search', UR),
+                ('set_flair', MFMix),
+                ('set_flair_csv', MFMix),
+                ('set_settings', MCMix),
+                ('set_stylesheet', MCMix),
+                ('submit', SubmitMixin),
+                ('subscribe', SubscribeMixin),
+                ('unsubscribe', SubscribeMixin),
+                ('update_settings', MCMix),
+                ('upload_image', MCMix))
 
     # Subreddit banned
     add_ban = _modify_relationship('banned', is_sub=True)
@@ -1010,9 +1028,9 @@ class Subreddit(Messageable, Refreshable):
 
     def __init__(self, reddit_session, subreddit_name=None, json_dict=None,
                  fetch=False):
-        # Special case for when my_reddits is called as no name is returned so
-        # we have to extract the name from the URL.  The URLs are returned as:
-        # /r/reddit_name/
+        # Special case for when my_subreddits is called as no name is returned
+        # so we have to extract the name from the URL.  The URLs are returned
+        # as: /r/reddit_name/
         if not subreddit_name:
             subreddit_name = json_dict['url'].split('/')[2]
 
@@ -1042,27 +1060,18 @@ class Subreddit(Messageable, Refreshable):
         else:
             return
 
-    def search(self, query, *args, **kwargs):
-        """Return submissions that match the search query from this subreddit.
-
-        See http://www.reddit.com/help/search for more information on how to
-        build a search query.
-
-        """
-        return self.reddit_session.search(query, self, *args, **kwargs)
-
 
 class PRAWListing(RedditContentObject):
 
-    CHILD_ATTRIBUTE = None
-
     """An abstract class to coerce a listing into RedditContentObjects."""
 
+    CHILD_ATTRIBUTE = None
+
     def __init__(self, reddit_session, json_dict=None, fetch=False):
         super(PRAWListing, self).__init__(reddit_session, json_dict, fetch)
 
         if not self.CHILD_ATTRIBUTE:
-            raise NotImplemented('PRAWListing must be extended.')
+            raise NotImplementedError('PRAWListing must be extended.')
 
         child_list = getattr(self, self.CHILD_ATTRIBUTE)
         for i in range(len(child_list)):
@@ -1071,6 +1080,9 @@ class PRAWListing(RedditContentObject):
     def __contains__(self, item):
         return item in getattr(self, self.CHILD_ATTRIBUTE)
 
+    def __delitem__(self, index):
+        del getattr(self, self.CHILD_ATTRIBUTE)[index]
+
     def __getitem__(self, index):
         return getattr(self, self.CHILD_ATTRIBUTE)[index]
 
@@ -1080,6 +1092,9 @@ class PRAWListing(RedditContentObject):
     def __len__(self):
         return len(getattr(self, self.CHILD_ATTRIBUTE))
 
+    def __setitem__(self, index, item):
+        getattr(self, self.CHILD_ATTRIBUTE)[index] = item
+
     def __unicode__(self):
         return six.text_type(getattr(self, self.CHILD_ATTRIBUTE))
 
@@ -1090,10 +1105,11 @@ class UserList(PRAWListing):
 
     CHILD_ATTRIBUTE = 'children'
 
-    def _convert(self, reddit_session, data):
-        """Convert the data into a Redditor object."""
+    @staticmethod
+    def _convert(reddit_session, data):
+        """Return a Redditor object from the data."""
         retval = Redditor(reddit_session, data['name'], fetch=False)
-        retval.id = data['id'].split('_')[1]
+        retval.id = data['id'].split('_')[1]  # pylint: disable-msg=C0103,W0201
         return retval
 
 
@@ -1119,8 +1135,9 @@ class WikiPage(RedditContentObject):
     def edit(self, *args, **kwargs):
         """Edit the wiki page.
 
-        :param content: The content to set the wiki page to.
-        :param reason: The justification for the edit (optional).
+        Convenience function that utilizes
+        :meth:`.AuthenticatedReddit.edit_wiki_page` populating both the
+        `subreddit` and `page` parameters.
 
         """
         self.subreddit.edit_wiki_page(self.page, *args, **kwargs)
@@ -1132,10 +1149,13 @@ class WikiPageListing(PRAWListing):
 
     CHILD_ATTRIBUTE = '_tmp'
 
-    def _convert(self, reddit_session, data):
-        """Convert the data into a WikiPage object."""
+    @staticmethod
+    def _convert(reddit_session, data):
+        """Return a WikiPage object from the data."""
         # TODO: The _request_url hack shouldn't be necessary
+        # pylint: disable-msg=W0212
         subreddit = reddit_session._request_url.rsplit('/', 4)[1]
+        # pylint: enable-msg=W0212
         return WikiPage(reddit_session, subreddit, data, fetch=False)
 
 
@@ -1144,6 +1164,7 @@ def _add_aliases():
     import sys
     predicate = lambda x: inspect.isclass(x) and hasattr(x, '_methods')
     for _, cls in inspect.getmembers(sys.modules[__name__], predicate):
-        for name, method in cls._methods:  # pylint: disable-msg=W0212
-            setattr(cls, name, alias_function(method))
+        for name, mixin in cls._methods:  # pylint: disable-msg=W0212
+            setattr(cls, name, alias_function(getattr(mixin, name),
+                                              mixin.__name__))
 _add_aliases()
